#-*- coding=utf-8 -*-
#----------------------------------------------------------------------------
#- @File     : fsop.py (op is short for operate)
#- @Author   : Shizhengxian( NFS-china)
#- @DateTime : Mon, 11 Aug 2014 14:59:04 CST
#- @CopyRight: The Security Tools Group( NFS-china)
#-
#- @Brief : 文件共享的底层接口文件，图形界面通过调用对应的接口来操作，包括
#-        : 基本接口：
#-        : 1. 列出本地节点的共享；
#-        : 2. 列出局域网内正在工作的计算机；
#-        : 3. 列出远程某节点的共享；
#-        : 4. 浏览某节点的某共享目录；
#-        : 5. 对某个目录设置共享；
#-        : 6. 清除某目录的共享状态；
#----------------------------------------------------------------------------

import re
import os
import os.path
import fcntl
import operator
import struct
import socket


#----------------------------------------------------------------------------
#- @brief: 列出本地节点的共享.
#- 
#- @param: 无.
#-
#- @return: success, 返回本地共享列表集合.
#-          failed,  空列表.
#----------------------------------------------------------------------------
def ls_local_shares():
    '''返回值为[{'share_name':None, 'path':None, 'comment':None},...]的列表'''
    local_shares = [];

    try:
        smb_conf = '/etc/samba/smb.conf';
#smb_conf = 'smb.conf';
        #-- 打开samba的配置文件，文件必须存在 --#
        smb_stream = open( smb_conf, 'r');
        if smb_stream is not None :
            share_name = '';
            path       = '';
            comment    = '';

            #-- 逐行读取配置文件内容 --#
            for line in smb_stream :
                line = line.strip();

                #-- 一行的内容必须大于0 --#
                if len( line) > 0 :
                    #-- 如果是'['开头，则有可能是共享名 --#
                    if line[ 0] == '[' :
                        if len( share_name) > 0 :
                            #-- 过滤global域 --#
                            if share_name == 'global' :
                                share_name = '';
                                path       = '';
                                comment    = '';

                                continue;

                            #-- 得到共享名称 --#
                            item_dict = {};
                            item_dict[ 'share_name'] = share_name;
                            item_dict[ 'path']       = path;
                            item_dict[ 'comment']    = comment;
                            
                            #-- 插入缓冲总列表中 --#
                            local_shares.append( item_dict);
                            share_name = '';
                            path       = '';
                            comment    = '';
                        else :
                            pass;

                        #-- 看看是否配对']', 获取共享名称 --#
                        idx_rb = line.find(']');
                        if idx_rb > 1:
                            if line[ (idx_rb - 1)] != '$' :
                                share_name = line[ 1 : idx_rb];

                    #-- 获取共享名称的数据项，path/comment --#
                    if len( share_name) > 0 :
                        line_list = line.split();

                        #-- 获取注解信息 --#
                        if ( len( comment) == 0) and ( line_list[0] == 'comment') :
                            cm_idx = line.find('=');
                            comment = line[ (cm_idx + 1) : ].strip();


                        #-- 获取共享路径 --#
                        if ( len( path) == 0) and ( line_list[0] == 'path') :
                            p_idx = line.find('=');
                            path = line[ (p_idx + 1) : ].strip();

            #-- 关闭文件 --#
            smb_stream.close();

            #-- 把最后一个共享名称放入列表中 --#
            if len( share_name) > 0 :
                item_dict = {};
                item_dict[ 'share_name'] = share_name;
                item_dict[ 'path']       = path;
                item_dict[ 'comment']    = comment;
                
                #-- 插入尾部 --#
                local_shares.append( item_dict);

            #-- 根据share_name进行排序 --#
            local_shares.sort( key=operator.itemgetter( 'share_name'));

    #-- 发送异常，清空列表 --#
    except Exception, e :
        while len( local_shares) :
            local_shares.pop();
        print '<Error>: ' + e.message;

    #-- 返回共享列表 --#
    return local_shares;
#---- End of function: ls_local_shares -------------------------------------#


#----------------------------------------------------------------------------
#- @brief: 比较两个IP地址的大小，这个只能做内部函数使用.
#- 
#- @param: ip1, IP地址一.
#- @param: ip2, IP地址二.
#-
#- @return: 大于返回1，相等返回0，小于返回-1.
#----------------------------------------------------------------------------
def ip_addr_cmp( ip1='', ip2='') :
    ret = 0;

#-- 把IP字符串转换成整数，该方式不靠谱，废弃 --#
#ip1_num = struct.unpack('I', socket.inet_aton( ip1));
#ip2_num = struct.unpack('I', socket.inet_aton( ip2));

#ret = 0 if ip1_num == ip2_num else 1 if ip1_num > ip2_num else -1;

    #-- 把IP分割成成四个独立的数字字符串，然后在转成数字进行比较 --#
    ip1_list = ip1.split('.');
    ip2_list = ip2.split('.');

    #-- 合法才继续，这里不做检测，因为该函数为内部使用，必须是合法IP地址 --#
    if int( ip1_list[0]) == int( ip2_list[0]) :
        #-- 第一个相等，检测第二个 --#
        if int( ip1_list[1]) == int( ip2_list[1]) :
            #-- 第二相等，检测第三个段 --#
            if int( ip1_list[2]) == int( ip2_list[2]) :
                #-- 第三相等，检测第四个段 --#
                if int( ip1_list[3]) > int( ip2_list[3]) :
                    ret = 1;
                else :
                    ret = -1;
            elif int( ip1_list[2]) > int( ip2_list[2]) : 
                ret = 1;
            else :
                ret = -1;
        elif int( ip1_list[1]) > int( ip2_list[1]) : 
            ret = 1;
        else :
            ret = -1;
    elif int( ip1_list[0]) > int( ip2_list[0]) : 
        ret = 1;
    else :
        ret = -1;

    return ret;
#---- End of function: ip_addr_cmp -----------------------------------------#


#----------------------------------------------------------------------------
#- @brief: 对HOST列表进行排序，这个是用在ls_working_nodes里面的.
#- 
#- @param: hosts_list，主机列表结合，里面的元素都是字典.
#-
#- @return: 返回排序后的host集合.
#----------------------------------------------------------------------------
def hosts_list_sort( hosts_list = []) :
    ret_hosts = [];

    hosts_list_size = len( hosts_list);

    #-- 空参数，让我干啥子求 --#
    if hosts_list_size > 0 :
        i = 0;

        #-- 使用选择排序算了，懒得写其它的 --#
        while ( i < (hosts_list_size - 1)) :
            min_host = hosts_list[ i].get( 'host');

            #-- 获得最小的元素下标 --#
            k = i;      #-- 记录最小元素的下标 --#
            j = i + 1;
            while ( j < hosts_list_size) :
                ret = ip_addr_cmp( min_host, hosts_list[ j].get( 'host'));
                if ret > 0 :
                    min_host = hosts_list[ j].get( 'host');
                    k = j;
                #-- 递增++ -#
                j = j + 1;

            #-- 交换元素 --#
            hosts_list[ k]['host'] = hosts_list[ i].get( 'host');
            hosts_list[ i]['host'] = min_host;

            #-- i递增加1 --#
            i = i + 1;

    return ret_hosts;
#---- End of function: hosts_list_sort -------------------------------------#


#----------------------------------------------------------------------------
#- @brief: 列出局域网内正在工作的计算机.
#- 
#- @param: 无.
#-
#- @return: success, 以主机名列表集合.
#-          failed,  空列表.
#----------------------------------------------------------------------------
def ls_working_nodes():
    '''返回值为[{'host':None},...]的列表，目前暂且为一个host数据项'''
    working_nodes = [];
    ip_pat = '^\d+\.\d+\.\d+\.\d+$';

    try : 
        #-- 获取本地节点所属的计算机组 --#
        g_stream = os.popen( 'smbtree -D -N');
        if g_stream is not None :
            g_name = g_stream.readline();
        #-- 都要尝试关闭 --#
        g_stream.close();

        #-- 以防得不到组名，就用默认的WORKGROUP --#
        if len( g_name) == 0 :
            g_name = 'WORKGROUP';

        #-- 获取计算机组名成功，则获取正在工作的所有计算机的IP --#
        g_name = g_name.strip();
        if len( g_name) > 0 :
            wn_stream = os.popen( 'nmblookup ' + g_name);

            #-- 如果命令执行成功 --#
            if wn_stream is not None :
                #-- 去掉第一行解释说明 --#
                wn_stream.readline();

                #-- 一行一行的获取 --#
                for line in wn_stream :
                    #-- 每一行都要有字符 --#
                    line = line.strip();
                    if len( line) > 0 :
                        tmp_list = line.split();

                        #-- 匹配ip地址，模糊匹配 --#
                        m_ret = re.match( ip_pat, tmp_list[0]);
                        if m_ret is not None :
                            item_dict = {};
                            item_dict[ 'host'] = tmp_list[ 0];

                            #-- 把地址元素放入列表中 --#
                            working_nodes.append( item_dict);

                #-- 关闭wn_stream流 --#
                wn_stream.close();

                #-- 根据 host 进行排序 --#
                hosts_list_sort( working_nodes);

    #-- 发送异常时，清空列表 --#
    except Exception, e: 
        while len( working_nodes) :
            working_nodes.pop();
        print '<Error>: ' + e.message;
    
    #-- 返回IP地址集列表 --#
    return working_nodes;
#---- End of function: ls_working_nodes ------------------------------------#


#----------------------------------------------------------------------------
#- @brief: 列出远程某节点的共享.
#- 
#- @param: host, 主机名，一般为IPv4地址.
#- @param: user, 登录的用户名.
#- @param: password, 登录的用户密码.
#-
#- @return: success, 共享的目录名集合.
#-          failed,  空列表.
#----------------------------------------------------------------------------
def ls_remote_shares( host, user, password):
    '''返回值为[{'share_name':None, 'comment':None},...]的列表'''
    remote_shares = [];

    #-- 命令结构：smbclient -L //host/ [-U user[%password]] [-N] --#
    cmd_fmt = 'smbclient -L //';

    try :
        #-- 构建命令，用于列出指定远程节点的共享信息 --#
        if  ( type( host) == type('')) and (len( host) > 0) :
            cmd_fmt = cmd_fmt + host + '/ ';

            #-- 如果指定了用户名 --#
            if  ( type( user) == type('')) and (len( user) > 0) :
                cmd_fmt = cmd_fmt + '-U ' + user;

                #-- 是否指定了密码 --#
                if ( type ( password) == type('')) and ( len( password) > 0) :
                    cmd_fmt = cmd_fmt + '%' + password + ' ';
                else :
                    cmd_fmt = cmd_fmt + ' -N';
            else :
                cmd_fmt = cmd_fmt + '-N';

            #-- 错误信息直接丢弃 --#
            cmd_fmt = cmd_fmt + ' 2>/dev/null';

            #-- 开始执行命令，然后过滤得到共享名称 --#
            rs_stream = os.popen( cmd_fmt);
            if rs_stream is not None :
                #-- 逐行读取 --#
                for line in rs_stream :
                    line = line.strip();
                    val = line.find("NT_STATUS_LOGON_FAILURE")
                    if val > 0 :
                        return 2
                    val = line.find("NT_STATUS_ACCESS_DENIED")
                    if val > 0 :
                        return 3
                    if ( len( line) > 0) :
                        tmp_list = line.split();

                        #-- 如果一行被空格分割的只有一个单词，则肯定不是 --#
                        if len( tmp_list) < 2 :
                            continue;

                        #-- 如果是硬盘类型，则可能是共享目录 --#
                        idx_disk = line.find(' Disk');
                        if idx_disk > 0 :
                            #-- 下标之前的部分是共享名称 --#
                            share_name = line[ : idx_disk].strip();

                            #-- 过滤以$符结尾的 --#
                            if share_name[-1] != '$' :
                                item_dict = {};

                                #-- 共享名称 --#
                                item_dict[ 'share_name'] = share_name;

                                #-- 组织注解信息 --#
                                comment  = "";

                                #-- 得看有没有注释信息 --#
                                tmp_size = len( tmp_list);
                                if tmp_size > 2 :
                                    comment = line[ (idx_disk + len( ' Disk') + 1) : ];
                                else :
                                    comment = 'The ' + tmp_list[0] + ' sharing';

                                #-- 共享的注解 --#
                                item_dict[ 'comment'] = comment;

                                #-- 放入总的列表中保存 --#
                                remote_shares.append( item_dict);

                #-- 关闭文件流 --#
                rs_stream.close();

                #-- 按照share_name进行排序 --#
                remote_shares.sort( key=operator.itemgetter( 'share_name'));

    #-- 发生异常，清空列表 --#
    except Exception, e :
        while len( remote_shares) :
            remote_shares.pop();
        print '<Error>: ' + e.message ;

    #-- 返回列表集合 --#
    return remote_shares;
#---- End of function: ls_remote_shares ------------------------------------#


#----------------------------------------------------------------------------
#- @brief: 浏览远程某节点的共享，这个需要root权限.
#- 
#- @param: host, 主机名，一般为IPv4地址.
#- @param: share_name, 远程节点的共享名称.
#- @param: user, 登录的用户名.
#- @param: password, 登录的用户密码.
#-
#- @return: success, 共享的目录名集合.
#-          failed,  空列表.
#----------------------------------------------------------------------------
def browse_remote_share( host, share_name, user='', password=''):
    '''返回值为mnt_name，也就是成功挂载后的路径，最后界面退出之前要umount'''
    mnt_name = "";
    do_mnt   = False;
    
    try :
        #-- 构造挂载语句，由COS自带mount.cifs命令，则使用之 --#
        if type( host) == type('') and len( host) > 0 and \
           type( share_name) == type('') and len( share_name) > 0 :
            cmd_fmt = 'mount.cifs -o ';

            #-- 看看是否提供了用户 --#
            if len( user) > 0 :
                cmd_fmt += 'username=' + user + ',';

            #-- 密码指定不指定为空都行 --#
            cmd_fmt += 'password=' + password + ' ';
            
            #-- 添加host/share_name和挂载路径 --#
            mount_path = '/mnt/' + host + '-' + share_name;

            #-- 构件完整挂载命令 : --#
            #-- mount.cifs -o username=xxx,password= //127.0.0.1/Share /mnt/127.0.0.1-Share -#
            cmd_fmt += '//' + host + '/' + share_name + ' ' + mount_path;

            #-- 删除旧的 --#
            if os.path.exists( mount_path) :
                #-- 如果目录已经存在，在检测是否已经挂载 --#
                if os.path.isdir( mount_path) :
                    if os.path.ismount( mount_path) :
                        pass;
                    else :
                        do_mnt = True;
                #-- 是文件，则必须删除在创建目录 --#
                else :
                    os.unlink( mount_path);

                    #-- 创建目录 --#
                    os.mkdir( mount_path);
                    do_mnt = True;
            else : 
                os.mkdir( mount_path);
                do_mnt = True;

            #-- 新挂载 --#
            if do_mnt :
                #-- 开始执行挂载命令 --#
                os.system( cmd_fmt);

            #-- 弹出挂载目录的操作界面 --#
            browse_cmd = 'gnome-open ' + mount_path;
            os.system( browse_cmd);

            #-- 填挂载路径返回 --#
            mnt_name = mount_path;

    #-- 发生异常了，肯定置空返回 --#
    except Exception, e :
        mnt_name = "";
        print '<Error>: ' + e.message;

    return mnt_name;
#---- End of function: browse_remote_share ---------------------------------#


#----------------------------------------------------------------------------
#- @brief: 退出浏览远程共享文件，需要root权限.
#- 
#- @param: host, 主机名，一般为IPv4地址.
#- @param: share_name, 远程节点的共享名称.
#-
#- @return: 无.
#----------------------------------------------------------------------------
def browout_remote_share( host='', share_name='') :
    try :
        #-- 二者不能为空 --#
        if len( host) > 0 and len( share_name) > 0 :
            #-- ete. unmount /tmp/127.0.0.1-Share --#
            mount_path  = '/mnt/' + host + '-' + share_name;
            cmd_umount = 'umount ' + mount_path;

            #-- 检测路径是否存在，是否是一个目录 --#
            if os.path.exists( mount_path) and os.path.isdir( mount_path) :
                #-- 看看是否是挂载点 --#
                if os.path.ismount( mount_path) :
                    #-- 那么就得卸载，然后删除该目录 --#
                    umount_stream = os.popen( cmd_umount);
                    umount_stream.close();

                #-- 目录直接删除 --#
                os.rmdir( mount_path);

    except Exception, e :
        print '<Error>: ' + e.message;

#---- End of function: browout_remote_share --------------------------------#


#----------------------------------------------------------------------------
#- @brief: 清除左右边的斜杠.
#-
#- @param: path_str, 这里为路径字符串.etc. '/tmp/share' or '/tmp/share/'
#-
#- @return: 返回清除左右边斜杠的字符串.etc.'tmp/share'.
#----------------------------------------------------------------------------
#@staticmethod
def clear_rl_slash( path_str = '') :
    ret_str = '';

    try :
        #-- 字符串必须有字符 --#
        if len( path_str) > 0 :
            #-- 自定义去除左右斜杠功能 --#
            left = 0;  
            right = len( path_str);

            #-- 获取左下标 --#
            while path_str[ left] == '/' :
                left = left + 1;

            #-- 获取右下标 --#
            while path_str[ right - 1] == '/' :
                right = right - 1;

            ret_str = path_str[ left : right];
        
    except Exception, e :
        print '<Error>: ' + e.message;

    #-- 处理后的字符串 --#
    return ret_str;
#---- End of function: clear_rl_slash --------------------------------------#


#----------------------------------------------------------------------------
#- @brief: 获取目录的共享状态，即是否为已经共享.
#- 
#- @param: dir_name, 目录的绝对路径.
#-
#- @return: 是，返回True，不是共享，返回False.
#----------------------------------------------------------------------------
def get_share_state( dir_name) :
    share_state = False;

    try :
        #-- 获取本地共享列表，然后检测dir_name是否处于共享 --#
        local_shares      = ls_local_shares();
        local_shares_size = len( local_shares);
        if local_shares_size > 0 :
            #-- 逐个获取元素 --#
            for d in local_shares :
                path = d.get( 'path');

                #-- 处理最后一个‘/’符，再做比较，否则就会可能失败 --#
                path = clear_rl_slash( path);

                dir_name = clear_rl_slash( dir_name);

                #-- 比较路径是否相等，相等，则已经共享 --#
                if path == dir_name :
                    share_state = True;
                    #-- 退出循环 --#
                    break;

        #-- 销毁列表，可能python不用，但这是好习惯，特别是C --#
        while len( local_shares) :
            local_shares.pop();

    #-- 发生异常时，释放列表 --#
    except Exception, e :
        while len( local_shares) :
            local_shares.pop();
        print '<Error>: ' + e.message;

    #-- 根据返回判断是否处于共享状态 --#
    return share_state;
#---- End of function: get_share_state -------------------------------------#


#----------------------------------------------------------------------------
#- @brief: 设置本地目录为共享目录，如果是普通文件则什么都不做，这需要root权限.
#-
#- @param: dir_name, 目录的绝对路径.
#- 
#- @return: success, True; failed, False;
#----------------------------------------------------------------------------
def set_share_state( dir_name = ''):
    '''返回值，成功返回0，失败返回-1'''
    ok_flag = False;
    fs  = dir_name
    dir_name = fs.replace('//@//',' ')
    old_dir_name = dir_name

    try :
        #-- 共享名称真难搞定，重名了你怎么办 --#
        share_name = '';

        if ( len(dir_name) > 1) and (dir_name[0] == '/') and os.path.isdir( dir_name) :
            #-- 用于标志是否用过共享名称 --#
            no_share_name = True;

            #-- 把dir_name拆开，为了应对重名 --#
            ret_slash = clear_rl_slash( dir_name);
            dn_list = ret_slash.split('/');

            #-- 检测最后一个元素是否在共享列表中的共享名称出现 --#
            local_shares = ls_local_shares();
            if len( local_shares) > 0 :
                #-- 检测dn_list[ -1] --#
                for d in local_shares : 
                    if dn_list[ -1] == d.get( 'share_name') :
                        #-- 使用过了 -#
                        no_share_name = False;
                        break;

            #-- 共享名使用过，那我就用绝对路径，把'/'改为'-' --#
            if no_share_name :
                share_name = dn_list[ -1].replace(' ','N');
                #share_name = dn_list[ -1];
            else :
                share_name = ret_slash.replace( '/', '-');

            #-- 组织共享语句 --#
            share_cnt = '';
            share_cnt = share_cnt + '[' + share_name + ']\n';
            share_cnt = share_cnt + '    comment = The ' + share_name + ' sharing\n';
            share_cnt = share_cnt + '    path = ' + old_dir_name + '\n';
            #jjd share_cnt = share_cnt + '    path = ' + dir_name + '\n';
            share_cnt = share_cnt + '    public = yes\n';
            share_cnt = share_cnt + '    read only = yes\n\n';

            #-- samba配置文件路径 --#
            smb_conf = '/etc/samba/smb.conf';
#mb_conf = 'smb.conf';

            #-- 以追加的方式写文件，这样保证原子性 --#
            smb_fd = open( smb_conf, 'a');
            if smb_fd is not None :
                #-- 锁住文件，但是可以读，其实这里并不能保证锁得住，依赖OS --#
                fcntl.flock( smb_fd, fcntl.LOCK_EX);

                #-- 检测是否共享过 -#
                share_state = get_share_state( dir_name);
                if share_state == False :
                    #-- 把共享内容写入配置文件中 --#
                    smb_fd.write( share_cnt);
                    os.utime( smb_conf, None);

                #-- 改为成功标志 --#
                ok_flag = True;

                #-- 操作完成，解锁，关闭文件 --#
                fcntl.flock( smb_fd, fcntl.LOCK_UN);
                smb_fd.close();

    #-- 异常则输出错误信息 --#
    except Exception, e :
        ok_flag = False;
        print '<Error>: ' + e.message;

    return ok_flag;
#---- End of function: set_share_state -------------------------------------#


#----------------------------------------------------------------------------
#- @brief: 清除共享目录的共享状态，这需要root权限.
#-
#- @param: dir_name, 目录的绝对路径.
#- 
#- @return: success, True; failed, False.
#----------------------------------------------------------------------------
def clear_share_state( dir_name = ''):
    '''返回值，成功返回0，失败返回-1'''
    ok_flag = True;

    #-- 修改文件的局部内容真心恶心，OS怎么不提供这个操作呢 --#
    smb_conf = '/etc/samba/smb.conf';
#smb_conf = 'smb.conf';

    try :
        #-- 标志着是共享的 --#
        share_flag = False;
        share_name = '';

        #-- 这一步还是有必要的 --#
        if ( len(dir_name) > 1) and (dir_name[0] == '/') and os.path.isdir( dir_name) :
            local_shares = ls_local_shares();
            if len( local_shares) > 0 :
                for d in local_shares :
                    #-- 确实是共享目录 --#
                    if dir_name == d.get( 'path') :
                        share_flag = True;
                        share_name = d.get( 'share_name');
                        break;

            #-- 你是共享目录，那么就清除，开始干活 --#
            if share_flag :
                smb_conf_fd = open( smb_conf, 'r');
                if smb_conf_fd is not None :
                    #-- 获取全部内容，然后查找共享名称出现的位置，返回的是列表 --#
                    cnt_list = smb_conf_fd.readlines();

                    #-- 差点忘记关闭文件 --#
                    smb_conf_fd.close();
                    
                    #-- 共享域组织 --#
                    idx_sn     = 0;
                    share_area = '[' + share_name + ']';

                    #-- 得自己处理，index不可靠，尤其在左右空格比较多的时候 --#
                    for tmp_item in cnt_list :
                        #-- 找到，退出 --#
                        if share_area == tmp_item.strip() :
                            break;
                        #-- 下标加一，后期用于pop --#
                        idx_sn = idx_sn + 1;

                    #-- 检测是否有，有的话就清除 --#
                    while idx_sn < len( cnt_list) :
                        cnt_list.pop( idx_sn);

                        #-- 防止误删下一个共享域 --#
                        if idx_sn < len( cnt_list) :
                            tmp_item = cnt_list[ idx_sn].strip();
                            if (len( tmp_item) > 0) and (tmp_item[ 0] == '[') :
                                break;

                    #-- 把文件清空，然后再写 --#
                    smb_conf_fd = open( smb_conf, 'w');
                    if smb_conf_fd is not None :
                        #-- 把处理过后的列表写入文件 --#
                        smb_conf_fd.writelines( cnt_list);

                        #-- 关闭文件 --#
                        smb_conf_fd.close();

                    #-- 清空列表 --#
                    while len( cnt_list) :
                        cnt_list.pop();

                    #-- 算是成功 --#
                    ok_flag = True;

    #-- 操作文件可能会发生异常 --#
    except Exception, e :
        ok_flag = False;
        print '<Error>: ' + e.message + '---';

    #-- 成功标志 --#
    return ok_flag;
#---- End of function: clear_share_state -----------------------------------#


#----------------------------------------------------------------------------
#- @brief: 重新加载samba服务的配置，需要root权限.
#- 
#- @param: 无.
#-
#- @return: 无.
#----------------------------------------------------------------------------
def smb_svc_reload() :
    smb_reload = 'service smbd reload';

    try :
        #-- 执行重新加载命令 --#
        os.system( smb_reload);

    #-- 出现异常，我能怎么办 --#
    except Exception, e :
        print '<Error>: ' + e.message;
#---- End of function: smb_svc_reload --------------------------------------#


